==> zio-aws-lightsail_2.12-5.17.295.6-sources.jar: zio/aws/lightsail/model/GetLoadBalancerMetricDataRequest.scala <==
package zio.aws.lightsail.model
import java.time.Instant
import zio.aws.core.BuilderHelper
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  Timestamp,
  MetricPeriod,
  ResourceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetLoadBalancerMetricDataRequest(
    loadBalancerName: ResourceName,
    metricName: zio.aws.lightsail.model.LoadBalancerMetricName,
    period: MetricPeriod,
    startTime: Timestamp,
    endTime: Timestamp,
    unit: zio.aws.lightsail.model.MetricUnit,
    statistics: Iterable[zio.aws.lightsail.model.MetricStatistic]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest = {
    import GetLoadBalancerMetricDataRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
      .builder()
      .loadBalancerName(ResourceName.unwrap(loadBalancerName): java.lang.String)
      .metricName(metricName.unwrap)
      .period(MetricPeriod.unwrap(period): Integer)
      .startTime(Timestamp.unwrap(startTime): Instant)
      .endTime(Timestamp.unwrap(endTime): Instant)
      .unit(unit.unwrap)
      .statisticsWithStrings(statistics.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly =
    zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest
      .wrap(buildAwsValue())
}
object GetLoadBalancerMetricDataRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest =
      zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest(
        loadBalancerName,
        metricName,
        period,
        startTime,
        endTime,
        unit,
        statistics
      )
    def loadBalancerName: ResourceName
    def metricName: zio.aws.lightsail.model.LoadBalancerMetricName
    def period: MetricPeriod
    def startTime: Timestamp
    def endTime: Timestamp
    def unit: zio.aws.lightsail.model.MetricUnit
    def statistics: List[zio.aws.lightsail.model.MetricStatistic]
    def getLoadBalancerName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(loadBalancerName)
    def getMetricName
        : ZIO[Any, Nothing, zio.aws.lightsail.model.LoadBalancerMetricName] =
      ZIO.succeed(metricName)
    def getPeriod: ZIO[Any, Nothing, MetricPeriod] = ZIO.succeed(period)
    def getStartTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(startTime)
    def getEndTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(endTime)
    def getUnit: ZIO[Any, Nothing, zio.aws.lightsail.model.MetricUnit] =
      ZIO.succeed(unit)
    def getStatistics
        : ZIO[Any, Nothing, List[zio.aws.lightsail.model.MetricStatistic]] =
      ZIO.succeed(statistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ) extends zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly {
    override val loadBalancerName: ResourceName =
      zio.aws.lightsail.model.primitives.ResourceName(impl.loadBalancerName())
    override val metricName: zio.aws.lightsail.model.LoadBalancerMetricName =
      zio.aws.lightsail.model.LoadBalancerMetricName.wrap(impl.metricName())
    override val period: MetricPeriod =
      zio.aws.lightsail.model.primitives.MetricPeriod(impl.period())
    override val startTime: Timestamp =
      zio.aws.lightsail.model.primitives.Timestamp(impl.startTime())
    override val endTime: Timestamp =
      zio.aws.lightsail.model.primitives.Timestamp(impl.endTime())
    override val unit: zio.aws.lightsail.model.MetricUnit =
      zio.aws.lightsail.model.MetricUnit.wrap(impl.unit())
    override val statistics: List[zio.aws.lightsail.model.MetricStatistic] =
      impl
        .statistics()
        .asScala
        .map { item =>
          zio.aws.lightsail.model.MetricStatistic.wrap(item)
        }
        .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ): zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_3-5.17.150.1-sources.jar: zio/aws/lightsail/model/GetLoadBalancerMetricDataRequest.scala <==
package zio.aws.lightsail.model
import java.time.Instant
import zio.aws.core.BuilderHelper
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  Timestamp,
  MetricPeriod,
  ResourceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class GetLoadBalancerMetricDataRequest(
    loadBalancerName: ResourceName,
    metricName: zio.aws.lightsail.model.LoadBalancerMetricName,
    period: MetricPeriod,
    startTime: Timestamp,
    endTime: Timestamp,
    unit: zio.aws.lightsail.model.MetricUnit,
    statistics: Iterable[zio.aws.lightsail.model.MetricStatistic]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest = {
    import GetLoadBalancerMetricDataRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
      .builder()
      .loadBalancerName(ResourceName.unwrap(loadBalancerName): java.lang.String)
      .metricName(metricName.unwrap)
      .period(MetricPeriod.unwrap(period): Integer)
      .startTime(Timestamp.unwrap(startTime): Instant)
      .endTime(Timestamp.unwrap(endTime): Instant)
      .unit(unit.unwrap)
      .statisticsWithStrings(statistics.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly =
    zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest
      .wrap(buildAwsValue())
}
object GetLoadBalancerMetricDataRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest =
      zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest(
        loadBalancerName,
        metricName,
        period,
        startTime,
        endTime,
        unit,
        statistics
      )
    def loadBalancerName: ResourceName
    def metricName: zio.aws.lightsail.model.LoadBalancerMetricName
    def period: MetricPeriod
    def startTime: Timestamp
    def endTime: Timestamp
    def unit: zio.aws.lightsail.model.MetricUnit
    def statistics: List[zio.aws.lightsail.model.MetricStatistic]
    def getLoadBalancerName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(loadBalancerName)
    def getMetricName
        : ZIO[Any, Nothing, zio.aws.lightsail.model.LoadBalancerMetricName] =
      ZIO.succeed(metricName)
    def getPeriod: ZIO[Any, Nothing, MetricPeriod] = ZIO.succeed(period)
    def getStartTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(startTime)
    def getEndTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(endTime)
    def getUnit: ZIO[Any, Nothing, zio.aws.lightsail.model.MetricUnit] =
      ZIO.succeed(unit)
    def getStatistics
        : ZIO[Any, Nothing, List[zio.aws.lightsail.model.MetricStatistic]] =
      ZIO.succeed(statistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ) extends zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly {
    override val loadBalancerName: ResourceName =
      zio.aws.lightsail.model.primitives.ResourceName(impl.loadBalancerName())
    override val metricName: zio.aws.lightsail.model.LoadBalancerMetricName =
      zio.aws.lightsail.model.LoadBalancerMetricName.wrap(impl.metricName())
    override val period: MetricPeriod =
      zio.aws.lightsail.model.primitives.MetricPeriod(impl.period())
    override val startTime: Timestamp =
      zio.aws.lightsail.model.primitives.Timestamp(impl.startTime())
    override val endTime: Timestamp =
      zio.aws.lightsail.model.primitives.Timestamp(impl.endTime())
    override val unit: zio.aws.lightsail.model.MetricUnit =
      zio.aws.lightsail.model.MetricUnit.wrap(impl.unit())
    override val statistics: List[zio.aws.lightsail.model.MetricStatistic] =
      impl
        .statistics()
        .asScala
        .map { item =>
          zio.aws.lightsail.model.MetricStatistic.wrap(item)
        }
        .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerMetricDataRequest
  ): zio.aws.lightsail.model.GetLoadBalancerMetricDataRequest.ReadOnly =
    new Wrapper(impl)
}
